#!/usr/local/bin/perl 

use strict;
use MyBench;
use Getopt::Long;
use Time::HiRes qw(gettimeofday tv_interval);
use Digest::MD5 qw(md5_hex);
use DBI;

my($engine, $num_kids, $num_runs) = @ARGV;
$engine ||= 'MyISAM';
$num_kids ||= 10; $num_runs ||= 1000;

my $table = 'mytable_'. lc($engine);

my $callback = sub {
    my $id  = shift;
    my $dbh = DBI->connect('dbi:mysql:test', 'root', '', { RaiseError => 1 });
    my $sth1 = $dbh->prepare("SELECT * FROM $table WHERE id = ?");
    my $sth2 = $dbh->prepare("UPDATE $table SET body = ?, created_on = NOW() WHERE id = ?");
    my $cnt = 0;
    my @times = ();

    local $SIG{HUP} = sub { };
    sleep 600;

    while ($cnt < $num_runs) {
        my $v = int(rand(100_000));
        my $t0 = [gettimeofday];
        $sth1->execute($v);
        my $t1 = tv_interval($t0, [gettimeofday]);
        if ($cnt % 5 == 0) {
            $sth2->execute(md5_hex({}. rand(10000). gettimeofday()), $v);
            $sth2->finish;
        }
        push @times, $t1;
        $sth1->finish;
        $cnt++;
    }

    $dbh->disconnect();
    my @r = ($id, scalar(@times), min(@times), max(@times), avg(@times), tot(@times));
    return @r;
};

my @results = MyBench::fork_and_work($num_kids, $callback);
MyBench::compute_results($engine, @results);

exit;



